@@ -25,7 +25,7 @@
 """
 __all__ = ['PREFIX', 'INCLUDE_PATH']
 
-from path import path as Path
+from path import Path
 
 from .libarray_ptr import __version__, __requires__
 
